import React, { useEffect, useState } from 'react';

const Authentication = () => {

    const [loading, setLoading] = useState<boolean>(false);
    const [isAuthenticated, setIsAuthenticated] = useState<boolean>(false);
    const [userInfo, setUserInfo] = useState<string>('');

    useEffect(() => {
        const getUserInfo = async() => {
            const response = await fetch('bff/user');
            if (response.ok)
            {
                setUserInfo(await response.json());
                setIsAuthenticated(true);
            }
        }

        getUserInfo();
    }, []);
    
    const signIn = () => {
        setLoading(true);
        window.location.href = '/bff/login?returnUrl=/authentication';
        setLoading(false);
    };

    const signOut = async() => {
        const response = await fetch('/bff/logout');
        if (response.redirected) {
            window.location.href = response.url;
        }
        setIsAuthenticated(false);
    };

    const prettyJson = () => {
        return (
            <pre>{JSON.stringify(userInfo, null, 2)}</pre>
        );
    };    
    
    let contents = loading ? <p><em>Loading...</em></p> : prettyJson();
    
    return (
        <div>
            <h1>Authentication</h1>
            { !isAuthenticated && <button className="btn btn-primary" onClick={signIn}>Sign in</button> }
            { isAuthenticated && <button className="btn btn-primary" onClick={signOut}>Sign out</button> }
            <br/>
            <br/>
            <p>{contents}</p>
        </div>
    )
}

export {Authentication}