import React, { useState } from 'react';
import {
  BaseObject,
  Client,
  FieldGroup,
  FolderObjectTypeFilter,
  SelectedProperties
} from "../openapi-client/openapi";
import { getFieldValueFromBaseObject } from "../openapi-client/OpenApiUtilities";
import {
  Accordion,
  AccordionBody,
  AccordionHeader,
  AccordionItem,
  Button, Col,
  Form,
  FormGroup,
  Input,
  Label
} from "reactstrap";

const Folder = () => {
  const [loading, setLoading] = useState<boolean>(false);
  const [folderContents, setFolderContents] = useState<BaseObject[]>();
  const [open, setOpen] = useState('');
  const [folderId, setFolderId] = useState(812160);

  const fetchFolderContents = async () => {
    setLoading(true);
    const client = new Client('/openapi');
    const response = await client.getFolderObjectList(
      folderId,
      FolderObjectTypeFilter.Contents,
      undefined,
      undefined,
      SelectedProperties.TitleAndDescription,
      FieldGroup.None,
      ['FTITLE', 'VERSION', 'MODIFIED-ON|lng', 'FISHCHECKEDOUTBY'],
      true,
      false);
    setFolderContents(response);
    setLoading(false);
  }

  const toggle = (id: string) => {
    if (open === id) {
      setOpen('');
    } else {
      setOpen(id);
    }
  };

  const getFolderContents = () => {
    return (
      <div>
        <br />
        <p>Fields</p>
        <table className='table table-striped' aria-labelledby="tabelLabel">
          <thead>
            <tr>
              <th>Title</th>
              <th>Version</th>
              <th>Status</th>
              <th>Date modified</th>
              <th>Locked by</th>
            </tr>
          </thead>
          <tbody>
            {folderContents?.map(baseObject =>
              <tr key={baseObject.id}>
                <td>{baseObject.title}</td>
                <td>{getFieldValueFromBaseObject(baseObject, 'FTITLE')}</td>
                <td>{getFieldValueFromBaseObject(baseObject, 'VERSION')}</td>
                <td>{getFieldValueFromBaseObject(baseObject, 'MODIFIED-ON')}</td>
                <td>{getFieldValueFromBaseObject(baseObject, 'FISHCHECKEDOUTBY')}</td>
              </tr>
            )}

          </tbody>
        </table>
        <Accordion open={open} toggle={toggle}>
          <AccordionItem>
            <AccordionHeader targetId="1">Response as JSON</AccordionHeader>
            <AccordionBody accordionId="1">
              <pre>{JSON.stringify(folderContents, null, 2)}</pre>
            </AccordionBody>
          </AccordionItem>
        </Accordion>

      </div>
    )
  }

  let contents = loading ? <p><em>Loading...</em></p> : getFolderContents();

  return (
    <div>
      <h1>Get Folder Contents</h1>
      <div>
        <Form>
          <FormGroup row>
            <Label form="folderId" sm={2}>
              Folder id:
            </Label>
            <Col sm={10}>
              <Input type="number" id="folderId" value={folderId} onChange={e => setFolderId(Number(e.target.value))} />
            </Col>
          </FormGroup>
        </Form>
        <Button color="primary" onClick={fetchFolderContents}>Get items in Folder</Button>
        <br />
      </div>
      {contents}
    </div>
  )
}

export { Folder }
