import React, {useState} from 'react';
import {
    Client,
    FieldGroup,
    SelectedProperties,
    User,
} from "../openapi-client/openapi";
import {getFieldValue} from "../openapi-client/OpenApiUtilities";
import {Accordion, AccordionBody, AccordionHeader, AccordionItem, Button} from "reactstrap";

const My = () => {
    const [loading, setLoading] = useState<boolean>(false);
    const [mySettings, setMySettings] = useState<User>();
    const [open, setOpen] = useState('');

    const fetchMySettings = async () => {
        setLoading(true);
        const client = new Client('/openapi');
        const response = await client.getCurrentUser(SelectedProperties.TitleAndDescription, FieldGroup.Basic, [], false);
        setMySettings(response);
        setLoading(false);
    }

    const toggle = (id: string) => {
        if (open === id) {
            setOpen('');
        } else {
            setOpen(id);
        }
    };

    const getMySettings = () => {
        return (
            <div>
                <table className='table table-striped' aria-labelledby="tabelLabel">
                    <thead>
                    <tr>
                        <th>Property</th>
                        <th>Value</th>
                    </tr>
                    </thead>
                    <tbody>
                    <tr>
                        <td>Id</td>
                        <td>{mySettings?.id}</td>
                    </tr>
                    <tr>
                        <td>Title</td>
                        <td>{mySettings?.title}</td>
                    </tr>
                    <tr>
                        <td>Description</td>
                        <td>{mySettings?.description}</td>
                    </tr>
                    </tbody>
                </table>
                <br/>
                <p>Fields</p>
                <table className='table table-striped' aria-labelledby="tabelLabel">
                    <thead>
                    <tr>
                        <th>Name</th>
                        <th>Title</th>
                        <th>Description</th>
                        <th>Field value</th>
                    </tr>
                    </thead>
                    <tbody>
                    {mySettings?.fields?.map(field =>
                        <tr key={field.name}>
                            <td>{field.name}</td>
                            <td>{field.title}</td>
                            <td>{field.description}</td>
                            <td>{getFieldValue(field)}</td>
                        </tr>
                    )}

                    </tbody>
                </table>
                <Accordion open={open} toggle={toggle}>
                    <AccordionItem>
                        <AccordionHeader targetId="1">Response as JSON</AccordionHeader>
                        <AccordionBody accordionId="1">
                            <pre>{JSON.stringify(mySettings, null, 2)}</pre>
                        </AccordionBody>
                    </AccordionItem>
                </Accordion>
            </div>
        )
    }

    let contents = loading ? <p><em>Loading...</em></p> : getMySettings();

    return (
        <div>
            <h1>My</h1>
            <Button color="primary" onClick={fetchMySettings}>Get my Settings</Button>
            <br/>
            {contents}
        </div>
    )
}

export {My}