import React, { useState } from 'react';
import {
  Client,
  DocumentObject,
  FieldGroup,
  SelectedProperties
} from "../openapi-client/openapi";
import { getFieldValue } from "../openapi-client/OpenApiUtilities";
import { Accordion, AccordionBody, AccordionHeader, AccordionItem, Button, Col, Form, FormGroup, Input, Label } from "reactstrap";

const Topic = () => {
  const [loading, setLoading] = useState<boolean>(false);
  const [topicFields, setTopicFields] = useState<DocumentObject>();
  const [downloadLink, setDownloadLink] = useState<string>();
  const [open, setOpen] = useState('');
  const [topicLogicalId, setTopicLogicalId] = useState('GUID-382D0FFC-B7A8-418F-8652-9439A1C7F6DD');


  const fetchTopicFields = async () => {
    setDownloadLink(undefined);
    setLoading(true);
    const client = new Client('/openapi');
    const response = await client.getDocumentObjectByLogicalId(
      topicLogicalId,
      null,
      null,
      null,
      SelectedProperties.TitleAndDescription,
      FieldGroup.Basic,
      [],
      true
    );
    setTopicFields(response);
    setDownloadLink(response.links?.find(l => l.rel === 'Download')?.href);
    setLoading(false);
  }

  const toggle = (id: string) => {
    if (open === id) {
      setOpen('');
    } else {
      setOpen(id);
    }
  };

  const getTopicFields = () => {
    return (
      <div>
        <h4>Fields</h4>
        <table className='table table-striped' aria-labelledby="tabelLabel">
          <thead>
            <tr>
              <th>Name</th>
              <th>Title</th>
              <th>Description</th>
              <th>Field value</th>
            </tr>
          </thead>
          <tbody>
            {topicFields?.fields?.map(field =>
              <tr key={field.name}>
                <td>{field.name}</td>
                <td>{field.title}</td>
                <td>{field.description}</td>
                <td>{getFieldValue(field)}</td>
              </tr>
            )}

          </tbody>
        </table>
        <Accordion open={open} toggle={toggle}>
          <AccordionItem>
            <AccordionHeader targetId="1">Response as JSON</AccordionHeader>
            <AccordionBody accordionId="1">
              <pre>{JSON.stringify(topicFields, null, 2)}</pre>
            </AccordionBody>
          </AccordionItem>
        </Accordion>
      </div>
    )
  }

  let contents = loading ? <p><em>Loading...</em></p> : getTopicFields();

  return (
    <div>
      <h1>Topic</h1>
      <div>
        <Form>
          <FormGroup row>
            <Label form="topicId" sm={2}>
              Topic logical id:
            </Label>
            <Col sm={10}>
              <Input type="text" id="topicId" value={topicLogicalId} onChange={e => setTopicLogicalId(e.target.value)} />
            </Col>
          </FormGroup>
        </Form>
        <Button color="primary" onClick={fetchTopicFields}>Get Topic fields</Button>
        {downloadLink && <a href={downloadLink} target='_blank' download='{topicFields?.title}.xml' rel='noreferrer'>Download</a>}
        <br />
        <br />
      </div>
      {contents}
    </div>
  )
}

export { Topic }
