import {
    BaseObject,
    CardFieldValue,
    DateTimeFieldValue,
    FieldValue,
    LovFieldValue,
    MultiCardFieldValue,
    MultiDateTimeFieldValue,
    MultiLovFieldValue,
    MultiNumberFieldValue,
    MultiStringFieldValue, MultiTagFieldValue, MultiVersionFieldValue,
    NumberFieldValue,
    ObjectFieldValue,
    StringFieldValue,
    TagFieldValue,
    VersionFieldValue
} from "./openapi";

export function getFieldValue(fieldValue: FieldValue): string {
    if (fieldValue instanceof StringFieldValue) {
        return (fieldValue as StringFieldValue).value || '';
    }

    if(fieldValue instanceof DateTimeFieldValue) {
        return (fieldValue as DateTimeFieldValue).value?.toISOString() || '';
    }

    if (fieldValue instanceof NumberFieldValue) {
        return (fieldValue as NumberFieldValue).value?.toString() || '';
    }

    if (fieldValue instanceof LovFieldValue) {
        return (fieldValue as LovFieldValue).value?.title || '';
    }

    if (fieldValue instanceof CardFieldValue) {
        return (fieldValue as CardFieldValue).value?.title || '';
    }

    if (fieldValue instanceof TagFieldValue) {
        return (fieldValue as TagFieldValue).value?.title || '';
    }

    if (fieldValue instanceof VersionFieldValue) {
        return (fieldValue as VersionFieldValue).value?.toString() || '';
    }

    if (fieldValue instanceof ObjectFieldValue) {
        return (fieldValue as ObjectFieldValue).value?.toString() || '';
    }

    if (fieldValue instanceof MultiStringFieldValue) {
        return (fieldValue as MultiStringFieldValue).value?.join(", ") || '';
    }

    if (fieldValue instanceof MultiNumberFieldValue) {
        return (fieldValue as MultiNumberFieldValue).value?.join(", ") || '';
    }

    if (fieldValue instanceof MultiDateTimeFieldValue) {
        let values = (fieldValue as MultiDateTimeFieldValue).value?.map( fv => {
            return fv.toISOString();
        })

        return values?.join(", ") || '';
    }

    if (fieldValue instanceof MultiLovFieldValue) {
        let values = (fieldValue as MultiLovFieldValue).value?.map( fv => {
            return fv.id;
        })

        return values?.join(", ") || '';
    }

    if (fieldValue instanceof MultiCardFieldValue) {
        let values = (fieldValue as MultiCardFieldValue).value?.map( fv => {
            return fv.id;
        })

        return values?.join(", ") || '';
    }

    if (fieldValue instanceof MultiTagFieldValue) {
        let values = (fieldValue as MultiTagFieldValue).value?.map( fv => {
            return fv.id;
        })

        return values?.join(", ") || '';
    }

    if (fieldValue instanceof MultiVersionFieldValue) {
        return (fieldValue as MultiVersionFieldValue).value?.join(", ") || '';
    }

    return '';
}

export function getFieldValueFromBaseObject(baseObject: BaseObject, fieldName: string): string
{
    let fieldValue = baseObject.fields?.find(field => field.ishField?.name === fieldName);

    if (fieldValue !== undefined)
    {
        return getFieldValue(fieldValue);
    }

    return '';
}
