using Microsoft.AspNetCore.Authentication;
using Microsoft.AspNetCore.Authentication.Cookies;
using Microsoft.Extensions.Caching.Memory;

namespace ReactAndOpenApi.Security;

public class MemoryCacheSessionStore : ITicketStore
{
    private const string KeyPrefix = "AuthSessionStore-";
    private readonly TimeSpan _expireTimeSpan;
    private static readonly MemoryCache SessionStore = new(new MemoryCacheOptions());

    public MemoryCacheSessionStore(TimeSpan expireTimeSpan)
    {
        _expireTimeSpan = expireTimeSpan;
    }
    
    public async Task<string> StoreAsync(AuthenticationTicket ticket)
    {
        string key = KeyPrefix + Guid.NewGuid();
        await RenewAsync(key, ticket);
        return key;
    }

    public Task RenewAsync(string key, AuthenticationTicket ticket)
    {
        MemoryCacheEntryOptions options = new ();
        DateTimeOffset? expiresUtc = ticket.Properties.ExpiresUtc;
        if (expiresUtc.HasValue)
        {
            options.SetAbsoluteExpiration(expiresUtc.Value);
        }
        options.SetSlidingExpiration(_expireTimeSpan); 

        SessionStore.Set(key, ticket, options);

        return Task.CompletedTask;    }

    public Task<AuthenticationTicket?> RetrieveAsync(string key)
    {
        SessionStore.TryGetValue(key, out AuthenticationTicket? ticket);
        return Task.FromResult(ticket);
    }

    public Task RemoveAsync(string key)
    {
        SessionStore.Remove(key);
        return Task.CompletedTask;
    }
}